# TorrentFileQt

## Version 0.3.0

    - Added more fields the to "Edit" tab.
    - Added Drag and Drop for all tabs that only deal with torrent files.
    - Minor changes to GUI style look
    - Added support for creating magnet links
    - Improvements and Additions to unit testing suite.
    - Support for torrentfile version 0.7.0
    - improved updated Icons and readme information.
    - other bug fixes.

----------

## Version 0.2.0

    - Bug Fixes
    - lots of bug fixes
    - upgraded support to newest torrentfile version 0.5.0
    - pre-compiled executables for window.
    - Check Tab for re-checking torrent download completion
    - docstrings
    - screenshots for reame

----------

## Version 0.1.0

    - GUI front end to TorrentFile CLI
    - Unit testing framework
    - Initial code commits
    - PySide6 widgets
